@@ -1,8 +1,8 @@
 package t::Object::HandRoll::Sub;
 use strict;
 use warnings;
-use base qw( t::Object::HandRoll );
 use Object::LocalVars;
+Object::LocalVars->base_object( 't::Object::HandRoll' );
 
 give_methods our $self;
 
